@@ -23,7 +23,7 @@
 #'
 #'   ui <- fluidPage(
 #'     tags$h3("Rounded actionBution"),
-#'     circleButton(inputId = "btn1", icon = icon("cog")),
+#'     circleButton(inputId = "btn1", icon = icon("gear")),
 #'     circleButton(
 #'       inputId = "btn2",
 #'       icon = icon("sliders"),
@@ -51,26 +51,16 @@ circleButton <- function (inputId, icon = NULL, status = "default", size = "defa
   size <- match.arg(arg = size, choices = c("default", "lg", "sm", "xs"))
   attachShinyWidgetsDep(
     htmltools::tags$button(
-      id = inputId, type = "button", style = "outline: none;", `data-val` = value,
-      class = paste0("btn btn-", status, " action-button ",
-                     ifelse(size == "default", "btn-circle",
-                            paste0("btn-circle-", size))), tags$span(icon), ...
-    )
-  )
-}
-
-
-
-
-squareButton <- function (inputId, icon = NULL, status = "default", size = "default", ...)
-{
-  size <- match.arg(arg = size, choices = c("default", "lg", "sm", "xs"))
-  attachShinyWidgetsDep(
-    htmltools::tags$button(
-      id = inputId, type = "button", style = "outline: none;",
-      class = paste0("btn btn-", status, " action-button ",
-                     ifelse(size == "default", "btn-square",
-                            paste0("btn-square-", size))), icon, ...
+      id = inputId,
+      type = "button",
+      style = "outline: none;",
+      `data-val` = value,
+      class = paste0(
+        "btn btn-", status, " action-button ",
+        ifelse(size == "default", "btn-circle", paste0("btn-circle-", size))
+      ),
+      tags$span(icon),
+      ...
     )
   )
 }
